import { IResource, Resource } from '@aws-cdk/core';
import { Construct } from 'constructs';
/**
 * A parameter group.
 *
 * @stability stable
 */
export interface IClusterParameterGroup extends IResource {
    /**
     * The name of this parameter group.
     *
     * @stability stable
     */
    readonly parameterGroupName: string;
}
/**
 * A new cluster or instance parameter group
 */
declare abstract class ClusterParameterGroupBase extends Resource implements IClusterParameterGroup {
    /**
     * Imports a parameter group.
     *
     * @stability stable
     */
    static fromParameterGroupName(scope: Construct, id: string, parameterGroupName: string): IClusterParameterGroup;
    /**
     * The name of the parameter group
     */
    abstract readonly parameterGroupName: string;
}
/**
 * Properties for a cluster parameter group.
 *
 * @stability stable
 */
export interface ClusterParameterGroupProps {
    /**
     * Description for this parameter group.
     *
     * @default a CDK generated description
     * @stability stable
     */
    readonly description?: string;
    /**
     * Database family of this parameter group.
     *
     * @stability stable
     */
    readonly family: string;
    /**
     * The name of the cluster parameter group.
     *
     * @default A CDK generated name for the cluster parameter group
     * @stability stable
     */
    readonly dbClusterParameterGroupName?: string;
    /**
     * The parameters in this parameter group.
     *
     * @stability stable
     */
    readonly parameters: {
        [key: string]: string;
    };
}
/**
 * A cluster parameter group.
 *
 * @stability stable
 * @resource AWS::DocDB::DBClusterParameterGroup
 */
export declare class ClusterParameterGroup extends ClusterParameterGroupBase implements IClusterParameterGroup {
    /**
     * The name of the parameter group.
     *
     * @stability stable
     */
    readonly parameterGroupName: string;
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: ClusterParameterGroupProps);
}
export {};
